==> fairseq2-0.1.0-py3-none-any.whl: fairseq2/data/__init__.py <==
# Copyright (c) Meta Platforms, Inc. and affiliates.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE file in the root directory of this source tree.

from fairseq2.data.cstring import CString as CString
from fairseq2.data.data_pipeline import ByteStreamError as ByteStreamError
from fairseq2.data.data_pipeline import CollateOptionsOverride as CollateOptionsOverride
from fairseq2.data.data_pipeline import Collater as Collater
from fairseq2.data.data_pipeline import DataPipeline as DataPipeline
from fairseq2.data.data_pipeline import DataPipelineBuilder as DataPipelineBuilder
from fairseq2.data.data_pipeline import DataPipelineError as DataPipelineError
from fairseq2.data.data_pipeline import FileMapper as FileMapper
from fairseq2.data.data_pipeline import FileMapperOutput as FileMapperOutput
from fairseq2.data.data_pipeline import RecordError as RecordError
from fairseq2.data.data_pipeline import SequenceData as SequenceData
from fairseq2.data.data_pipeline import (
    get_last_failed_example as get_last_failed_example,
)
from fairseq2.data.data_pipeline import list_files as list_files
from fairseq2.data.data_pipeline import read_sequence as read_sequence
from fairseq2.data.data_pipeline import read_zipped_records as read_zipped_records
from fairseq2.data.typing import PathLike as PathLike
from fairseq2.data.typing import StringLike as StringLike
from fairseq2.data.typing import is_string_like as is_string_like
from fairseq2.data.vocabulary_info import VocabularyInfo as VocabularyInfo

==> fairseq2-0.3.0-py3-none-any.whl: fairseq2/data/__init__.py <==
# Copyright (c) Meta Platforms, Inc. and affiliates.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE file in the root directory of this source tree.

from __future__ import annotations

from fairseq2.data.data_pipeline import ByteStreamError as ByteStreamError
from fairseq2.data.data_pipeline import CollateOptionsOverride as CollateOptionsOverride
from fairseq2.data.data_pipeline import Collater as Collater
from fairseq2.data.data_pipeline import DataPipeline as DataPipeline
from fairseq2.data.data_pipeline import DataPipelineBuilder as DataPipelineBuilder
from fairseq2.data.data_pipeline import DataPipelineError as DataPipelineError
from fairseq2.data.data_pipeline import FileMapper as FileMapper
from fairseq2.data.data_pipeline import FileMapperOutput as FileMapperOutput
from fairseq2.data.data_pipeline import RecordError as RecordError
from fairseq2.data.data_pipeline import SequenceData as SequenceData
from fairseq2.data.data_pipeline import create_bucket_sizes as create_bucket_sizes
from fairseq2.data.data_pipeline import (
    get_last_failed_example as get_last_failed_example,
)
from fairseq2.data.data_pipeline import list_files as list_files
from fairseq2.data.data_pipeline import read_iterator as read_iterator
from fairseq2.data.data_pipeline import read_sequence as read_sequence
from fairseq2.data.data_pipeline import read_zipped_records as read_zipped_records
from fairseq2.data.memory import MemoryBlock as MemoryBlock
from fairseq2.data.vocabulary_info import VocabularyInfo as VocabularyInfo
